@@ -49,11 +49,11 @@ class Container(object):
         html[index] = piece
     return html
 
-  def __str__(self):
+  def __unicode__(self):
     "Get a description"
     if not hasattr(self, 'begin'):
       return self.__class__.__name__
-    return self.__class__.__name__ + '@' + str(self.begin)
+    return self.__class__.__name__ + '@' + unicode(self.begin)
 
   def escape(self, line, escapes = ContainerConfig.escapes):
     "Escape a line to appear in HTML"
@@ -65,27 +65,41 @@ class Container(object):
         line = line.replace(piece, escapes[piece])
     return line
 
-  def searchfor(self, type):
-    "Search for an embedded container of a given type recursively"
-    for element in self.contents:
-      if isinstance(element, Container):
-        if isinstance(element, type):
-          return element
-        result = element.searchfor(type)
-        if result:
-          return result
-    return None
-
   def searchall(self, type):
     "Search for all embedded containers of a given type"
     list = []
-    for element in self.contents:
-      if isinstance(element, Container):
-        if isinstance(element, type):
-          list.append(element)
-        list += element.searchall(type)
+    self.searchprocess(type,
+        lambda contents, index: list.append(contents[index]))
     return list
 
+  def searchremove(self, type):
+    "Search for all containers of a type and remove them"
+    list = []
+    self.searchprocess(type,
+        lambda contents, index: self.appendremove(list, contents, index))
+    return list
+
+  def appendremove(self, list, contents, index):
+    "Append to a list and remove from contents"
+    list.append(contents[index])
+    del contents[index]
+
+  def searchprocess(self, type, process):
+    "Search for all embedded containers and process them"
+    for index, element in enumerate(self.contents):
+      if isinstance(element, Container):
+        element.searchprocess(type, process)
+      if isinstance(element, type):
+        process(self.contents, index)
+
+  def extracttext(self):
+    "Search for all the strings and extract the text they contain"
+    text = ''
+    strings = self.searchall(StringContainer)
+    for string in strings:
+      text += string.contents[0]
+    return text
+
   def restyle(self, type, restyler):
     "Restyle contents with a restyler function"
     for index, element in enumerate(self.contents):
@@ -113,6 +127,15 @@ class Container(object):
     while len(container.contents) > 0:
       self.contents.insert(index, container.contents.pop())
 
+  def debug(self, level = 0):
+    "Show the contents in debug mode"
+    if not Trace.debugmode:
+      return
+    Trace.debug('  ' * level + unicode(self))
+    for element in self.contents:
+      if isinstance(element, Container):
+        element.debug(level + 1)
+
 class BlackBox(Container):
   "A container that does not output anything"
 
@@ -121,6 +144,15 @@ class BlackBox(Container):
     self.output = EmptyOutput()
     self.contents = []
 
+class LyXFormat(BlackBox):
+  "Read the lyxformat command"
+
+  def process(self):
+    "Show warning if version < 276"
+    version = int(self.header[1])
+    if version < 276:
+      Trace.error('Warning: unsupported format version ' + str(version))
+
 class StringContainer(Container):
   "A container for a single string"
 
@@ -136,7 +168,7 @@ class StringContainer(Container):
     self.contents = [replaced]
     if ContainerConfig.string['startcommand'] in replaced and len(replaced) > 1:
       # unprocessed commands
-      Trace.error('Unknown command at ' + str(self.parser.begin) + ': '
+      Trace.error('Unknown command at ' + unicode(self.parser.begin) + ': '
           + replaced.strip())
 
   def changeline(self, line):
@@ -152,13 +184,13 @@ class StringContainer(Container):
         line = line.replace(piece, map[piece])
     return line
   
-  def __str__(self):
+  def __unicode__(self):
     length = ''
     descr = ''
     if len(self.contents) > 0:
-      length = str(len(self.contents[0]))
+      length = unicode(len(self.contents[0]))
       descr = self.contents[0].strip()
-    return 'StringContainer@' + str(self.begin) + '(' + str(length) + ')'
+    return 'StringContainer@' + unicode(self.begin) + '(' + unicode(length) + ')'
 
 class Constant(StringContainer):
   "A constant string"
@@ -167,8 +199,8 @@ class Constant(StringContainer):
     self.contents = [text]
     self.output = MirrorOutput()
 
-  def __str__(self):
-    return 'Constant'
+  def __unicode__(self):
+    return 'Constant: ' + self.contents[0]
 
 class TaggedText(Container):
   "Text inside a tag"
@@ -183,8 +215,8 @@ class TaggedText(Container):
   def complete(self, contents, tag, breaklines=False):
     "Complete the tagged text and return it"
     self.contents = contents
-    self.tag = tag
-    self.breaklines = breaklines
+    self.output.tag = tag
+    self.output.breaklines = breaklines
     return self
 
   def constant(self, text, tag, breaklines=False):
@@ -192,6 +224,6 @@ class TaggedText(Container):
     constant = Constant(text)
     return self.complete([constant], tag, breaklines)
 
-  def __str__(self):
-    return 'Tagged <' + self.tag + '>'
+  def __unicode__(self):
+    return 'Tagged <' + self.output.tag + '>'
 
