@@ -36,6 +36,7 @@ from gen.table import *
 from gen.image import *
 from gen.structure import *
 from gen.inset import *
+from gen.float import *
 from math.array import *
 
 
@@ -50,15 +51,15 @@ class ContainerFactory(object):
       types[start] = globals()[typename]
     self.tree = ParseTree(types)
 
-  def create(self, reader):
-    "Get the container and parse it"
+  def createsome(self, reader):
+    "Parse a list of containers"
     #Trace.debug('processing "' + reader.currentline() + '"')
     type = self.tree.find(reader)
     container = type.__new__(type)
     container.__init__()
     container.start = reader.currentline().strip()
     self.parse(container, reader)
-    return container
+    return self.getlist(container)
 
   def parse(self, container, reader):
     "Parse a container"
@@ -88,6 +89,13 @@ class ContainerFactory(object):
       return container.ending
     return None
 
+  def getlist(self, container):
+    "Get a list of containers from one."
+    "If appropriate, change the container for another(s)"
+    if not isinstance(container, PlainLayout):
+      return [container]
+    return container.contents
+
 class ParseTree(object):
   "A parsing tree"
 
