@@ -69,7 +69,14 @@ class Newline(Container):
 
   def process(self):
     "Process contents"
-    self.html = ['<br/>']
+    self.html = ['<br/>\n']
+
+class NewPage(Newline):
+  "A new page"
+
+  def process(self):
+    "Process contents"
+    self.html = ['<p><br/>\n</p>\n']
 
 class Appendix(Container):
   "An appendix to the main document"
@@ -93,8 +100,8 @@ class ListItem(Container):
     tag = TaggedText().complete(self.contents, 'li', True)
     self.contents = [tag]
 
-  def __str__(self):
-    return self.type + ' item @ ' + str(self.begin)
+  def __unicode__(self):
+    return self.type + ' item @ ' + unicode(self.begin)
 
 class DeeperList(Container):
   "A nested list"
@@ -109,10 +116,10 @@ class DeeperList(Container):
       Trace.error('Empty deeper list')
       return
 
-  def __str__(self):
-    result = 'deeper list @ ' + str(self.begin) + ': ['
+  def __unicode__(self):
+    result = 'deeper list @ ' + unicode(self.begin) + ': ['
     for element in self.contents:
-      result += str(element) + ', '
+      result += unicode(element) + ', '
     return result[:-2] + ']'
 
 class ERT(Container):
