@@ -76,10 +76,6 @@ class TaggedOutput(ContentsOutput):
 
   def gethtml(self, container):
     "Return the HTML code"
-    if hasattr(container, 'breaklines'):
-      self.breaklines = container.breaklines
-    if hasattr(container, 'tag'):
-      self.tag = container.tag
     html = [self.getopen(container)]
     html += ContentsOutput.gethtml(self, container)
     html.append(self.getclose(container))
@@ -144,7 +140,7 @@ class FooterOutput(object):
     if FooterOutput.author and not Options.nocopy:
       html.append('<hr/>\n')
       year = datetime.date.today().year
-      html.append('<p>Copyright (C) ' + str(year) + ' ' + FooterOutput.author
+      html.append('<p>Copyright (C) ' + unicode(year) + ' ' + FooterOutput.author
           + '</p>\n')
     html.append('</div>\n')
     html.append('</body>\n')
