@@ -92,7 +92,7 @@ class FormulaBit(Container):
     self.original += string
     pos.skip(string)
 
-  def __str__(self):
+  def __unicode__(self):
     "Get a string representation"
     return self.__class__.__name__ + ' read in ' + self.original
 
@@ -188,7 +188,7 @@ class WholeFormula(FormulaBit):
       if self.parsearrayend(pos):
         return
       bit = self.factory.parsebit(pos)
-      #Trace.debug(bit.original + ' -> ' + str(bit.gethtml()))
+      #Trace.debug(bit.original + ' -> ' + unicode(bit.gethtml()))
       self.add(bit)
 
   def process(self):
