@@ -84,7 +84,10 @@ class IndexEntry(Link):
 
   def process(self):
     "Put entry in index"
-    name = self.parser.parameters['name'].strip()
+    if 'name' in self.parameters:
+      name = self.parameters['name'].strip()
+    else:
+      name = self.extracttext()
     self.name = self.escape(name, IndexEntry.namescapes)
     self.key = self.escape(self.name, IndexEntry.keyescapes)
     if not self.key in IndexEntry.entries:
@@ -92,25 +95,10 @@ class IndexEntry(Link):
       IndexEntry.entries[self.key] = list()
     self.index = len(IndexEntry.entries[self.key])
     IndexEntry.entries[self.key].append(self)
-    self.anchor = 'entry-' + self.key + '-' + str(self.index)
+    self.anchor = 'entry-' + self.key + '-' + unicode(self.index)
     self.url = '#index-' + self.key
     self.contents = [Constant(u'↓')]
 
-class LayoutIndexEntry(IndexEntry):
-  "An entry with the name in a layout"
-
-  def process(self):
-    "Read entry from layout and put in index"
-    name = ''
-    layout = self.contents[0]
-    for element in layout.contents:
-      if isinstance(element, StringContainer):
-        name += element.contents[0]
-      else:
-        name += ' '
-    self.parser.parameters['name'] = name
-    IndexEntry.process(self)
-
 class PrintIndex(Container):
   "Command to print an index"
 
@@ -144,7 +132,7 @@ class PrintIndex(Container):
     arrows = []
     for entry in entries:
       link = Link().complete(u'↑', 'index-' + entry.key,
-          '#entry-' + entry.key + '-' + str(entry.index))
+          '#entry-' + entry.key + '-' + unicode(entry.index))
       arrows += [link, Constant(u', \n')]
     return arrows[:-1]
 
@@ -215,9 +203,8 @@ class FlexURL(URL):
 
   def process(self):
     "Read URL from contents"
-    text = self.searchfor(StringContainer).contents[0]
-    self.url = self.escape(text)
-    self.contents = [Constant(self.url)]
+    strings = self.searchall(StringContainer)
+    self.contents = strings
 
 class LinkOutput(object):
   "A link pointing to some destination"
